@@ -1,6 +1,7 @@
 from pathlib import Path
 
 import fire
+import hypergol
 
 from hypergol.name_string import NameString
 from hypergol.hypergol_project import HypergolProject
@@ -17,6 +18,7 @@ def create_project(projectName, dryrun=None, force=None):
         - ``tasks`` with ``__init__.py``
         - ``models`` with ``__init__.py``
         - ``models\blocks`` with ``__init__.py``
+        - ``notebooks``
         - ``tests``
 
     Executables:
@@ -30,6 +32,7 @@ def create_project(projectName, dryrun=None, force=None):
         - ``README.md``
         - ``LICENSE`` <- Don't forget to add current year and your name or change it to the one you want
         - ``pylintrc``
+        - ``notebooks\\HypergolExample.ipynb``
 
     Parameters
     ----------
@@ -55,15 +58,21 @@ def create_project(projectName, dryrun=None, force=None):
     project.create_blocks_directory()
     project.render_simple(templateName='__init__.py.j2', filePath=Path(project.blocksPath, '__init__.py'))
     project.create_tests_directory()
+    project.create_notebooks_directory()
+    requirementsContent = project.render(
+        templateName='requirements.txt.j2',
+        templateData={'hypergolVersion': hypergol.__version__},
+        filePath=Path(project.projectDirectory, 'requirements.txt')
+    )
     makeVenvScript = project.render_executable(templateName='make_venv.sh.j2', templateData={}, filePath=Path(project.projectDirectory, 'make_venv.sh'))
     runTestScript = project.render_executable(templateName='run_tests.sh.j2', templateData={}, filePath=Path(project.projectDirectory, 'run_tests.sh'))
     runPylintScript = project.render_executable(templateName='run_pylint.sh.j2', templateData={}, filePath=Path(project.projectDirectory, 'run_pylint.sh'))
-    requirementsContent = project.render_simple(templateName='requirements.txt.j2', filePath=Path(project.projectDirectory, 'requirements.txt'))
     gitignoreContent = project.render_simple(templateName='.gitignore.j2', filePath=Path(project.projectDirectory, '.gitignore'))
     readmeContent = project.render_simple(templateName='README.md.j2', filePath=Path(project.projectDirectory, 'README.md'))
     licenseContent = project.render_simple(templateName='LICENSE.j2', filePath=Path(project.projectDirectory, 'LICENSE'))
     pylintrcContent = project.render_simple(templateName='pylintrc.j2', filePath=Path(project.projectDirectory, 'pylintrc'))
-    allContent = (makeVenvScript, runTestScript, runPylintScript, requirementsContent, gitignoreContent, readmeContent, licenseContent, pylintrcContent)
+    notebookContent = project.render_notebook(notebookName='HypergolExample.ipynb', filePath=Path(project.notebooksPath, 'HypergolExample.ipynb'))
+    allContent = (makeVenvScript, runTestScript, runPylintScript, requirementsContent, gitignoreContent, readmeContent, licenseContent, pylintrcContent, notebookContent)
     return project.cli_final_message(creationType='Project', name=projectName, content=allContent)
 
 
