@@ -5,7 +5,7 @@ class JobReport(Repr):
     """Class for passing information from the tasks to the pipeline
     """
 
-    def __init__(self, jobId, success, results=None):
+    def __init__(self, jobId, exceptions, results=None):
         """
 
         Parameters
@@ -13,11 +13,11 @@ class JobReport(Repr):
 
         jobId: int
             Id of the job executed
-        success: bool
-            Outcome of the job
+        exceptions: bool
+            Was there any exception during execute()
         results: dict
             Any information to be passed to the finish() function
         """
         self.jobId = jobId
-        self.success = success
+        self.exceptions = exceptions
         self.results = results or {}
